@@ -1,3 +1,5 @@
+/* vim: set ts=8 sw=8 noexpandtab: */
+
 /* The CSS Theme Engine for Gtk+.
  * Copyright (C) 2008 Robert Staudinger
  *
@@ -17,14 +19,11 @@
  * MA 02110-1301, USA.
  */
 
-#include <ccss/ccss.h>
 #include <gmodule.h>
 #include <gtk/gtk.h>
-
-#include "gce-functions.h"
-#include "gce-node.h"
 #include "gce-style.h"
 #include "gce-rc-style.h"
+#include "config.h"
 
 /* This prototypes silence some warnings. */
 G_MODULE_EXPORT void		theme_init		(GTypeModule *module);
@@ -35,19 +34,14 @@ G_MODULE_EXPORT const gchar *	g_module_check_init	(GModule *module);
 G_MODULE_EXPORT void 
 theme_init (GTypeModule *module)
 {
-	ccss_function_t const	*vtable;
-
 	gce_rc_style_register_type (module);
 	gce_style_register_type (module);
-
-	vtable = gce_functions_get_vtable ();
-	ccss_init (vtable);
 }
 
 G_MODULE_EXPORT void 
 theme_exit (void)
 {
-	ccss_shutdown ();
+	/* Nothing to do. */
 }
 
 G_MODULE_EXPORT GtkRcStyle*
